@@ -644,24 +644,4 @@ plot.comprisk <-  function (x, pointwise.ci=1, hw.ci=0,
 } ## }}}
 
 
-"summary.comprisk" <- function (object,digits = 3,...) {
-  if (!inherits(object, 'comprisk')) stop ("Must be a comprisk object")
-  
-  if (is.null(object$gamma)==TRUE) semi<-FALSE else semi<-TRUE
-    
-  # We print information about object:  
-  cat("Competing risks Model \n\n")
-  
-  modelType<-object$model
-  #if (modelType=="additive" || modelType=="rcif") 
- 
-  if (sum(object$obs.testBeq0)==FALSE) cat("No test for non-parametric terms\n") else
-  timetest(object,digits=digits); 
-
-  if (semi) { cat("Parametric terms : \n"); coef(object); cat("   \n"); }
-
-  cat("  Call: \n")
-  dput(attr(object, "Call"))
-  cat("\n")
-}
 
