@@ -11,20 +11,21 @@ double *times,*betaS,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,
 	*timepowtest,*convc;
 int *n,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 *semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent;
-{
+{ // {{{
+  // {{{ allocation and reading of data from R
   matrix *X,*cX,*A,*AI,*cumAt[*antclust],*VAR,*Z;
   vector *VdB,*risk,*SCORE,*W,*Y,*Gc,*DELTA,*CAUSE,*bhat,*pbhat,*beta,*xi,
     *rr,*rowX,*difbeta,*qs,*bhatub,*betaub,*dcovs,*pcovs,*zi,*rowZ,*zgam; 
   vector *cumhatA[*antclust],*cumA[*antclust],*bet1,*gam,*dp,*dp1,*dp2; 
-  int ps,sing,sc,c,i,j,k,l,s,it,convproblems=0; 
+  int osilent,convt,ps,sing,sc,c,i,j,k,l,s,it,convproblems=0,pointswithconv=0; 
   double time,sumscore,totrisk,zgamt, 
 	 *vcudif=calloc((*Ntimes)*(*px+1),sizeof(double));
   long idum;
   float gasdev(),expdev(),ran1();
-  idum=*rani;
-  ps=(*px); 
+  idum=*rani; ps=(*px); 
 
   if (*semi==0) { 
+    osilent=silent[0]; silent[0]=0; 
     malloc_mat(*n,*px,X); malloc_mat(*n,*px,cX); 
     if (*trans==2) {malloc_mat(*n,*pg,Z);malloc_vecs(*pg,&zgam,&gam,&zi,&rowZ,NULL);}
     malloc_mats(ps,ps,&A,&AI,&VAR,NULL); 
@@ -48,26 +49,34 @@ int *n,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 //      if (*trans==0) for(j=0;j<*pg;j++)  ME(Z,c,j)=zsem[j*(*n)+c];
     }
 
+    // }}}
+    
 	 
- sc=0;
+sc=0; pointswithconv=0; 
 for (s=0;s<*Ntimes;s++)
 {
    time=times[s]; est[s]=time; score[s]=time; var[s]=time;
+   convt=1; 
 
   for (it=0;it<*Nit;it++)
   {
     totrisk=0; 
-    for (j=0;j<*n;j++) { 
+
+    for (j=0;j<*n;j++) { // {{{ computation of P1 and DP1  and observed response 
       VE(risk,j)=(x[j]>=time); totrisk=totrisk+VE(risk,j);
       extract_row(X,j,xi); 
-
       VE(bhat,j)=vec_prod(xi,bet1); 
 
       if (*trans==1) {VE(pbhat,j)=1-exp(-VE(bhat,j));
 	scl_vec_mult(1-VE(pbhat,j),xi,dp);}
       if (*trans==2) {
 	VE(pbhat,j)=1-exp(-exp(VE(bhat,j))); 
-	scl_vec_mult((1-VE(pbhat,j))*exp(VE(bhat,j)),xi,dp); }
+	scl_vec_mult((1-VE(pbhat,j))*exp(VE(bhat,j)),xi,dp); 
+      }
+      if (*trans==6) {
+	VE(pbhat,j)=1-exp(-VE(bhat,j)); 
+	scl_vec_mult((1-VE(pbhat,j)),xi,dp); 
+      }
       if (*trans==3) {
 	    VE(pbhat,j)=exp(VE(bhat,j))/(1+exp(VE(bhat,j))); 
 	scl_vec_mult(exp(VE(bhat,j))/pow((1+exp(VE(bhat,j))),2),xi,dp);
@@ -77,14 +86,10 @@ for (s=0;s<*Ntimes;s++)
          VE(pbhat,j)=exp(VE(bhat,j)); 
 	 scl_vec_mult(exp(VE(pbhat,j)),xi,dp);
       }
-      if (*trans==8) { // not implemented 
-	extract_row(Z,j,zi); vec_star(zi,gam,zgam); zgamt=vec_sum(zgam); 
-	VE(rr,j)=exp(zgamt);  
-	VE(pbhat,j)=1-(VE(bhat,j)*VE(rr,j))/(1+(VE(bhat,j)*VE(rr,j))); 
-	scl_vec_mult((1-VE(pbhat,j))*VE(rr,j),xi,xi); 
-	scl_vec_mult((1-VE(pbhat,j))*VE(rr,j)*VE(bhat,j),zi,zi); 
-	for (c=0;c<*px;c++) VE(dp,c)=VE(xi,c); 
-	for (c=*px;c<ps;c++) VE(dp,c)=VE(zi,c-*px); }
+      if (*trans==5) {
+         VE(pbhat,j)=VE(bhat,j); 
+	 scl_vec_mult(1,xi,dp);
+      }
       replace_row(cX,j,dp); 
 
       VE(Y,j)=((x[j]<=time) & (cause[j]==*CA))*1;
@@ -93,17 +98,18 @@ for (s=0;s<*Ntimes;s++)
 	scl_vec_mult(VE(Y,j),dp,dp); vec_add(dp,qs,qs); }
       if (KMc[j]<0.001) VE(Y,j)=(VE(Y,j)/0.001)-VE(pbhat,j); 
       else VE(Y,j)=(VE(Y,j)/KMc[j])-VE(pbhat,j);
-    }
+    } // }}}
+
     totrisk=vec_sum(risk); MtA(cX,cX,A); 
-    invertS(A,AI,silent[0]); sing=0; 
+    invertS(A,AI,osilent); sing=0; 
     // head_matrix(cX); print_mat(A); print_mat(AI); 
 
     if (fabs(ME(AI,0,0))<.0000001) {
-      convproblems=1; 
+      convproblems=1; convt=0; silent[s]=1;
       for (c=0;c<ps;c++) VE(beta,c)=0; 
       for (c=0;c<*px;c++) VE(bet1,c)=betaS[c]; 
       sing=1;
-      if (*silent==0) printf("Non-invertible design at time %lf\n",time); 
+      if (osilent==0) printf("Non-invertible design at time %lf \n",time); 
       it=*Nit-1;  
     }
     if (sing==0) {
@@ -118,9 +124,9 @@ for (s=0;s<*Ntimes;s++)
 
       if (isnan(vec_sum(SCORE))) {
 	printf("missing values in SCORE %ld \n",(long int) s); 
-	convproblems=1; 
+	convproblems=1; convt=0; silent[s]=2;
 	it=*Nit-1; 
-	for (c=0;c<ps;c++) VE(beta,c)=0; 
+	for (c=0;c<ps;c++) { VE(beta,c)=0; VE(SCORE,c)=99; }
 	for (c=0;c<*px;c++) VE(bet1,c)=betaS[c]; 
 	}
     }
@@ -135,6 +141,7 @@ for (s=0;s<*Ntimes;s++)
 
 vec_zeros(VdB); mat_zeros(VAR); 
 
+if (convt==1 ) {
    for (j=0;j<*antclust;j++) {vec_zeros(cumA[j]);vec_zeros(cumhatA[j]);}
    for (i=0;i<*n;i++) { 
       j=clusters[i]; 
@@ -154,9 +161,11 @@ vec_zeros(VdB); mat_zeros(VAR);
       for(k=0;k<ps;k++) 
       for(c=0;c<ps;c++) ME(VAR,k,c)=ME(VAR,k,c)+VE(dp2,k)*VE(dp2,c); 
 
-      if (*resample==1) 
+      if (*resample==1) {
       for (c=0;c<*px;c++) {l=j*(*px)+c; biid[l*(*Ntimes)+s]=VE(dp2,c);}
+      }
    }
+}
 
    for (i=1;i<ps+1;i++) {
       var[i*(*Ntimes)+s]=ME(VAR,i-1,i-1); 
@@ -175,7 +184,7 @@ vec_zeros(VdB); mat_zeros(VAR);
 	      gamiid,resample,timepow,clusters,antclust,timepowtest,silent,convc);
   }
  
-  if (convproblems==1) silent[0]=2; 
+  if (convproblems>0) convc[0]=1; 
   if (*semi==0) { 
     free_mats(&VAR,&X,&cX,&A,&AI,NULL); 
     if (*trans==2) {free_mats(&Z,NULL); free_vecs(&zgam,&gam,&zi,&rowZ,NULL);}
@@ -189,7 +198,8 @@ vec_zeros(VdB); mat_zeros(VAR);
 
   }
 free(vcudif); 
-}
+} // }}}
+
 
 void itfitsemi(times,Ntimes,x,delta,cause,
 	       KMc,z,antpers,px,Nit,
@@ -204,7 +214,8 @@ double *times,*x,*KMc,*z,*score,*hess,*est,*var,*test,*testOBS,
 	*convc;
 int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 *semi,*pg,*trans,*CA,*line,*detail,*resample,*clusters,*antclust,*silent;
-{
+{ 
+  // {{{ allocation and reading of data from R
   matrix *ldesignX,*A,*AI,*cdesignX,*ldesignG,*cdesignG;
   matrix *S,*dCGam,*CGam,*ICGam,*VarKorG,*dC,*XZ,*ZZ,*ZZI,*XZAI; 
   matrix *Ct,*C[*Ntimes],*Acorb[*Ntimes],*tmpM1,*tmpM2,*tmpM3,*tmpM4; 
@@ -218,11 +229,12 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
   int sing,itt,i,j,k,l,s,c,pmax,totrisk,convproblems=0, 
       *n= calloc(1,sizeof(int)), *nx= calloc(1,sizeof(int)),
       *robust= calloc(1,sizeof(int));
+  int idum,fixedcov,osilent; 
   double time,dummy,dtime,timem;
   double *vcudif=calloc((*Ntimes)*(*px+1),sizeof(double)),
 	 *inc=calloc((*Ntimes)*(*px+1),sizeof(double));
   double lrr,fabs(), pow(); 
-  int idum,fixedcov; 
+  osilent=silent[0]; silent[0]=0; 
   // float gasdev(),expdev(),ran1();
   idum=*rani; robust[0]=1; fixedcov=1; 
   n[0]=antpers[0]; nx[0]=antpers[0];
@@ -252,6 +264,8 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 
   if (*px>=*pg) pmax=*px; else pmax=*pg; 
   for (j=0;j<*pg;j++) VE(gam,j)=gamma[j]; 
+  // }}}
+  
 
   if (fixedcov==1) {
     for (c=0;c<*antpers;c++) {
@@ -291,10 +305,7 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 //	      else scl_vec_mult(time,zi,zi); 
 	    }
 	    if (*trans==2) { 
-//	      if (timem>0)  { 
 		for (l=0;l<*pg;l++) lrr=lrr+VE(gam,l)*VE(zi,l)*pow(time,timepow[l]); 
-//	    } 
-//	      else lrr=VE(pghat,j);  
 	      VE(rr,j)=exp(lrr);  
 	      VE(plamt,j)=1-exp(-exp(VE(pbhat,j))*VE(rr,j)); 
 	      scl_vec_mult((1-VE(plamt,j))*exp(VE(pbhat,j))*VE(rr,j),xi,xi); 
@@ -325,6 +336,24 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 //	      if (timem>0) 
 	      for (l=0;l<*pg;l++) VE(zi,l)= pow(time,timepow[l])*VE(zi,l); 
            }
+	   if (*trans==5) {
+	      for (l=0;l<*pg;l++) lrr=lrr+VE(gam,l)*VE(zi,l)*pow(time,timepow[l]); 
+	      VE(rr,j)=lrr;  
+	      VE(plamt,j)=VE(pbhat,j)*exp(lrr); 
+	      scl_vec_mult(exp(lrr),xi,xi); 
+	      scl_vec_mult(VE(plamt,j),zi,zi); 
+//	      if (timem>0) 
+	      for (l=0;l<*pg;l++) VE(zi,l)= pow(time,timepow[l])*VE(zi,l); 
+           }
+           if (*trans==6) { 
+	      for (l=0;l<*pg;l++) lrr=lrr+VE(gam,l)*VE(zi,l)*pow(time,timepow[l]); 
+	      VE(rr,j)=exp(lrr);  
+	      VE(plamt,j)=1-exp(-VE(pbhat,j)*VE(rr,j)); 
+	      scl_vec_mult((1-VE(plamt,j))*VE(rr,j),xi,xi); 
+	      scl_vec_mult((1-VE(plamt,j))*(VE(pbhat,j))*VE(rr,j),zi,zi); 
+	      for (l=0;l<*pg;l++) VE(zi,l)= pow(time,timepow[l])*VE(zi,l); 
+	    }
+
 	   // }}}
 
 	    replace_row(cdesignX,j,xi); replace_row(cdesignG,j,zi); 
@@ -338,13 +367,13 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 	    else VE(Y,j)=(VE(Y,j)/KMc[j])-VE(plamt,j);
 	  }
 	  MtA(cdesignX,cdesignX,A); 
-	  invertS(A,AI,silent[0]); sing=0; 
+	  invertS(A,AI,osilent); sing=0; 
 
           if (fabs(ME(AI,0,0))<.0000001) {
-             convproblems=1; 
-             if (*silent==0) printf("non-invertible design at time %lf\n",time); 
-             itt=*Nit-1;  
+             convproblems=1;  silent[s]=1; 
+             if (osilent==0) printf("Iteration %d: non-invertible design at time %lf\n",itt,time); 
 	     for (k=1;k<=*px;k++) inc[k*(*Ntimes)+s]=0; 
+	     sing=1;
           }
 
 	  if (sing==0) { 
@@ -381,12 +410,12 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 	 }
 	} /* s=1,...Ntimes */
 
-      invertS(CGam,ICGam,silent[0]); Mv(ICGam,IZGdN,dgam); vec_add(gam,dgam,gam); 
+      invertS(CGam,ICGam,osilent); Mv(ICGam,IZGdN,dgam); vec_add(gam,dgam,gam); 
 
-      if (isnan(vec_sum(dgam)) && *silent==0) {
-        if (convproblems==1) convproblems=3;  else convproblems=2; 
-	printf("missing values in dgam %ld \n",(long int) s);
-	vec_zeros(gam); 
+      if (isnan(vec_sum(dgam))) {
+         if (convproblems==1) convproblems=3;  else convproblems=2; 
+         if (osilent==1) printf("missing values in dgam %ld \n",(long int) s);
+	 vec_zeros(gam); 
       }
 
       dummy=0; for (k=0;k<*pg;k++)  dummy=dummy+fabs(VE(dgam,k)); 
@@ -394,7 +423,8 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
       for (s=0;s<*Ntimes;s++) {
 	vM(Acorb[s],dgam,korG); 
 	est[s]=times[s]; var[s]=times[s]; 
-	for (k=1;k<=*px;k++)  { est[k*(*Ntimes)+s]=
+	for (k=1;k<=*px;k++)  { 
+            est[k*(*Ntimes)+s]=
             est[k*(*Ntimes)+s]+inc[k*(*Ntimes)+s]-VE(korG,k-1); 
 	  dummy=dummy+fabs(inc[k*(*Ntimes)+s]-VE(korG,k-1)); 
 	  /* printf(" %lf ",est[k*(*Ntimes)+s]); printf(" \n");*/ }
@@ -403,9 +433,9 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
 
       if (*detail==1) { 
 	printf(" iteration %d %d \n",itt,*Nit); 
-	printf("Total score %lf \n",dummy); 
-	printf(" gamma parmaeters \n"); print_vec(gam); 
-	printf(" change in gamma \n"); print_vec(dgam); }
+	printf("Total sum of changes %lf \n",dummy); 
+	printf("Gamma parameters \n"); print_vec(gam); 
+	printf("Change in Gamma \n"); print_vec(dgam); }
 
     } /*itt lkke */ 
 
@@ -443,7 +473,7 @@ int *antpers,*px,*Ntimes,*Nit,*cause,*delta,*sim,*antsim,*rani,*weighted,
   for (j=0;j<*pg;j++) {gamma[j]=VE(gam,j);
     for (k=0;k<*pg;k++) {vargamma[k*(*pg)+j]=ME(RobVargam,j,k);}}
 
-  if (convproblems==1) silent[0]=2; 
+  if (convproblems>=1) convc[0]=convproblems; 
   if (*sim==1) {
     comptestfunc(times,Ntimes,px,est,var,vcudif,antsim,test,testOBS,Ut,simUt,W4t,weighted,antclust,gamma2,line,timepowtest);
   }
